<?xml version='1.0' encoding="UTF-8" ?>
<!--
****************************************************************
DITA to XSL-FO Stylesheet
Module: Figure list stylesheet
Copyright © 2009-2011 Antenna House, Inc. All rights reserved.
Antenna House is a trademark of Antenna House, Inc.
URL    : http://www.antennahouse.com/
E-mail : info@antennahouse.com
****************************************************************
-->
<xsl:stylesheet version="2.0" 
 xmlns:fo="http://www.w3.org/1999/XSL/Format" 
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:xs="http://www.w3.org/2001/XMLSchema"
 xmlns:axf="http://www.antennahouse.com/names/XSL/Extensions"
 xmlns:ahf="http://www.antennahouse.com/names/XSLT/Functions/Document"
 xmlns:psmi="http://www.CraneSoftwrights.com/resources/psmi"
 exclude-result-prefixes="xs ahf"
>

<!-- 
 function:	Generate figure list template
 param:		none
 return:	(fo:page-sequence)
 note:      Current is booklist/figurelist		
 -->
<xsl:template name="genFigureList" >
    <xsl:if test="$figureCountMap/figurecount[@count &gt; 0]">
        <psmi:page-sequence>
            <xsl:choose>
                <xsl:when test="ancestor::*[contains(@class,' bookmap/frontmatter ')]">
                    <xsl:choose>
                        <xsl:when test="$pOnlinePdf">
                            <xsl:copy-of select="ahf:getAttributeSet('atsPageSeqFrontmatterOnline')"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:copy-of select="ahf:getAttributeSet('atsPageSeqFrontmatter')"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:if test="not(preceding-sibling::*) and 
                                  not(parent::*/preceding-sibling::*[contains(@class,' map/topicref ')])">
                        <xsl:attribute name="initial-page-number" select="'1'"/>
                    </xsl:if>
                    <fo:static-content flow-name="rgnFrontmatterBeforeLeft">
                        <xsl:choose>
                            <xsl:when test="$pOnlinePdf">
                                <xsl:call-template name="frontmatterBeforeRight"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:call-template name="frontmatterBeforeLeft"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnFrontmatterBeforeRight">
                        <xsl:call-template name="frontmatterBeforeRight"/>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnFrontmatterAfterLeft">
                        <xsl:choose>
                            <xsl:when test="$pOnlinePdf">
                                <xsl:call-template name="frontmatterAfterRight"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:call-template name="frontmatterAfterLeft"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnFrontmatterAfterRight">
                        <xsl:call-template name="frontmatterAfterRight"/>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnFrontmatterBlankBody">
                        <xsl:call-template name="makeBlankBlock"/>
                    </fo:static-content>
                    <fo:flow flow-name="xsl-region-body">
                        <xsl:call-template name="genFigureListMain"/>
                    </fo:flow>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="$pOnlinePdf">
                            <xsl:copy-of select="ahf:getAttributeSet('atsPageSeqBackmatterOnline')"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:copy-of select="ahf:getAttributeSet('atsPageSeqBackmatter')"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <fo:static-content flow-name="rgnFrontmatterBeforeLeft">
                        <xsl:choose>
                            <xsl:when test="$pOnlinePdf">
                                <xsl:call-template name="frontmatterBeforeRight"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:call-template name="frontmatterBeforeLeft"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnBackmatterBeforeRight">
                        <xsl:call-template name="backmatterBeforeRight"/>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnBackmatterAfterLeft">
                        <xsl:choose>
                            <xsl:when test="$pOnlinePdf">
                                <xsl:call-template name="backmatterAfterRight"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:call-template name="backmatterAfterLeft"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnBackmatterAfterRight">
                        <xsl:call-template name="backmatterAfterRight"/>
                    </fo:static-content>
                    <fo:static-content flow-name="rgnBackmatterBlankBody">
                        <xsl:call-template name="makeBlankBlock"/>
                    </fo:static-content>
                    <fo:flow flow-name="xsl-region-body">
                        <xsl:call-template name="genFigureListMain"/>
                    </fo:flow>
                </xsl:otherwise>
            </xsl:choose>
        </psmi:page-sequence>
    </xsl:if>
</xsl:template>


<!-- 
 function:	Figure list main template
 param:		none
 return:	fo:block
 note:		
 -->
<xsl:template name="genFigureListMain">
    <fo:block>
        <xsl:copy-of select="ahf:getAttributeSet('atsBase')"/>
        <!-- Title -->
        <fo:block>
            <xsl:copy-of select="ahf:getAttributeSet('atsFmHeader1')"/>
            <xsl:attribute name="id">
                <xsl:value-of select="$cFigureListId"/>
            </xsl:attribute>
            <fo:marker marker-class-name="{$cTitleBody}">
                <fo:inline><xsl:copy-of select="$cFigureListTitle"/></fo:inline>
            </fo:marker>
            <xsl:value-of select="$cFigureListTitle"/>
        </fo:block>
        <!-- Make contents -->
		<xsl:apply-templates select="$map" mode="MAKE_FIGURE_LIST"/>
    </fo:block>
</xsl:template>
 
<!-- 
 function:	General templates for figure list
 param:		none
 return:	
 note:		none
 -->
<xsl:template match="*" mode="MAKE_FIGURE_LIST">
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<xsl:template match="text()" mode="MAKE_FIGURE_LIST"/>
<xsl:template match="*[contains(@class, ' bookmap/bookmeta ')]" mode="MAKE_FIGURE_LIST"/>

<!-- Frontmatter -->
<xsl:template match="*[contains(@class,' bookmap/frontmatter ')]" mode="MAKE_FIGURE_LIST" priority="2" >
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<!-- Backmatter -->
<xsl:template match="*[contains(@class,' bookmap/backmatter ')]" mode="MAKE_FIGURE_LIST" priority="2" >
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<!-- frontmatter/backmatter contents -->

<!-- booklist is skipped in dita2fo_convmerged.xsl -->
<xsl:template match="*[contains(@class,' bookmap/booklists ')]" mode="MAKE_FIGURE_LIST" priority="2" >
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/toc ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!--Ignore TOC -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/figurelist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/tablelist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/abbrevlist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Abbrevlist should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/trademarklist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Trademarklist should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/bibliolist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Bibliolist should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/glossarylist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Glossarylist have topicref child element. -->
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/indexlist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Indexlist -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/booklist ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Booklist should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/notices ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Notices have topicref child element. -->
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/preface ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Preface has topicref child element. -->
    <xsl:apply-templates mode="MAKE_TABLE_LIST"/>
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/dedication ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Dedication should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/colophon ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Colophon should have a href attribute. -->
</xsl:template>

<xsl:template match="*[contains(@class,' bookmap/amendments ')][not(@href)]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- Aamendments should have a href attribute. -->
</xsl:template>

<!-- topicgroup is skipped in dita2fo_convmerged.xsl -->
<xsl:template match="*[contains(@class,' mapgroup-d/topicgroup ')]" mode="MAKE_FIGURE_LIST" priority="2" >
    <!-- topicgroup create group without affecting the hierarchy. -->
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<!-- Ignore reltable contents -->
<xsl:template match="*[contains(@class,' map/reltable ')]" mode="MAKE_FIGURE_LIST" />

<!-- 
 function:	templates for topicref
 param:		none
 return:	Figure list line
 note:		Process all of the map/topicref contents.
 -->
<xsl:template match="*[contains(@class,' map/topicref ')][@href]" mode="MAKE_FIGURE_LIST">
    <xsl:variable name="topicRef" select="."/>
    <xsl:variable name="id" select="substring-after(@href, '#')"/>
    <xsl:variable name="topicContent" select="if (string($id)) then key('topicById',$id) else ()" as="element()?"/>
    <xsl:variable name="topicRefCount" select="ahf:countTopicRef(.)" as="xs:integer"/>

    <xsl:for-each select="$topicContent/descendant::*[contains(@class, ' topic/fig ')][child::*[contains(@class, ' topic/title ')]]">
        <xsl:variable name="fig" select="."/>
        <xsl:variable name="figId" select="if (@id) then string(ahf:getIdAtts($fig,$topicRef,true())) else ahf:generateIdByTrCount($fig,$topicRefCount)" as="xs:string"/>
        <xsl:variable name="figTitle" as="node()*">
            <xsl:apply-templates select="$fig/*[contains(@class,' topic/title ')]" mode="MAKE_FIGURE_LIST">
                <xsl:with-param name="prmTopicRef"    select="$topicRef"/>
                <xsl:with-param name="prmNeedId"      select="false()"/>
            </xsl:apply-templates>
        </xsl:variable>
        <xsl:call-template name="makeFigListLine">
            <xsl:with-param name="prmId"    select="$figId"/>
            <xsl:with-param name="prmTitle" select="$figTitle"/>
        </xsl:call-template>
    </xsl:for-each>
    <!-- Navigate to lower level -->
    <xsl:apply-templates mode="MAKE_FIGURE_LIST"/>
</xsl:template>

<!-- 
    function:	Make figure title FO
    param:		prmTopicRef, prmNeedId
    return:	    fo:inline * 2
    note:		This template must return exactly 2 <fo:inline> elements.
-->
<xsl:template match="*[contains(@class, ' topic/fig ')]/*[contains(@class, ' topic/title ')]" priority="2" mode="MAKE_FIGURE_LIST">
    <xsl:param name="prmTopicRef" required="yes"  as="element()"/>
    <xsl:param name="prmNeedId"   required="yes"  as="xs:boolean"/>
    
    <fo:inline>
        <xsl:value-of select="ahf:getFigTitlePrefix($prmTopicRef,parent::*)"/>
        <xsl:text>&#x00A0;</xsl:text>
        <xsl:text>&#x00A0;</xsl:text>
    </fo:inline>
    <fo:inline>
        <xsl:copy-of select="ahf:getUnivAtts(.,$prmTopicRef,$prmNeedId)"/>
        <xsl:apply-templates>
            <xsl:with-param name="prmTopicRef"    select="$prmTopicRef"/>
            <xsl:with-param name="prmNeedId"      select="$prmNeedId"/>
        </xsl:apply-templates>
    </fo:inline>
</xsl:template>

<!-- 
 function:	Make figure list line
 param:		prmId, prmTitle
 return:	fo:list-block
 note:		Changed to use fo:list-block. 2011-09-09 t.makita
 -->
<xsl:template name="makeFigListLine">
    <xsl:param name="prmId"    required="yes" as="xs:string"/>
    <xsl:param name="prmTitle" required="yes" as="node()*"/>

    <fo:list-block>
        <xsl:copy-of select="ahf:getAttributeSet('atsFigListBlock')"/>
        <fo:list-item>
            <xsl:copy-of select="ahf:getAttributeSet('atsFigListItem')"/>
            <fo:list-item-label>
                <xsl:copy-of select="ahf:getAttributeSet('atsFigListLabel')"/>
                <fo:block>
                    <fo:basic-link internal-destination="{$prmId}">
                        <xsl:copy-of select="$prmTitle[1]"/>
                    </fo:basic-link>
                </fo:block>
            </fo:list-item-label>
            <fo:list-item-body>
                <xsl:copy-of select="ahf:getAttributeSet('atsFigListBody')"/>
                <fo:block>
                    <fo:basic-link internal-destination="{$prmId}">
                        <xsl:copy-of select="$prmTitle[2]"/>
                    </fo:basic-link>
                    <fo:leader leader-length.optimum="0pt">
                        <xsl:copy-of select="ahf:getAttributeSet('atsFigListLeader')"/>
                    </fo:leader>
                    <fo:inline keep-with-next="always">
                        <fo:leader>
                            <xsl:copy-of select="ahf:getAttributeSet('atsFigListLeader')"/>
                        </fo:leader>
                    </fo:inline>
                    <fo:basic-link internal-destination="{$prmId}">
                        <fo:page-number-citation ref-id="{$prmId}" />
                    </fo:basic-link>
                </fo:block>
            </fo:list-item-body>
        </fo:list-item>
    </fo:list-block>
</xsl:template>

</xsl:stylesheet>
